@@ -195,6 +195,11 @@ _END
 <meta http-equiv="content-type" content="application/xhtml+xml; charset=UTF-8" />
 _END
 <meta http-equiv="content-type" content="application/xhtml+xml; charset=EUC-JP" />
+_END
+			<<'_END' => <<'_END',
+<?xml version='1.0' encoding='SHIFT_JIS'?>
+_END
+<?xml version='1.0' encoding='EUC-JP'?>
 _END
 		}.each_pair do |src, dst|
 			dst_char = NKF::EUC
